@@ -1,12 +1,12 @@
 
-NNS.ANOVA.bin<- function(control,treatment,confidence.interval=NULL,plot=TRUE,extend=NULL){
+NNS.ANOVA.bin<- function(control,treatment,confidence.interval=NULL,tails=NULL,plot=TRUE){
 
         mean.of.means <- mean(c(mean(control),mean(treatment)))
 
   #Continuous CDF for each variable from Mean of Means
-        LPM_ratio.1 <- LPM(1,mean.of.means,control)/(LPM(1,mean.of.means,control)+UPM(1,mean.of.means,control))
+        LPM_ratio.1 <- LPM.ratio(1,mean.of.means,control)
 
-        LPM_ratio.2 <- LPM(1,mean.of.means,treatment)/(LPM(1,mean.of.means,treatment)+UPM(1,mean.of.means,treatment))
+        LPM_ratio.2 <- LPM.ratio(1,mean.of.means,treatment)
 
 
   #Continuous CDF Deviation from 0.5
@@ -34,29 +34,49 @@ if(is.null(confidence.interval)){
 
 if(!is.null(confidence.interval)){
         #Upper end of CDF confidence interval for control mean
-            a=UPM.VaR((confidence.interval+(1-confidence.interval)/2),1,control,extend = extend)
-            b=UPM.VaR(.5,1,control,extend=extend)
+        if(tails=="Both"){
+            CI=confidence.interval+(1-confidence.interval)/2
+        }
+        if(tails=="Left" | tails=="Right") {
+            CI=confidence.interval
+        }
+
+
+            a=UPM.VaR(CI,1,control,extend = "yes")
+            b=mean(control)
             if(plot==TRUE){
-        abline(v=max(a,b),
-              col="green",lwd=4, lty=3)
-            text(max(a,b),
-              pos=4,0.75,"mu+",col="green")}
+            if(tails=="Both"|tails=="Right"){
+              abline(v=max(a,b),col="green",lwd=4,lty=3)
+              text(max(a,b),pos=2,0.75,"mu+",col="green")
+              text(max(a,b),pos=4,0.75,paste0((1-CI)*100,"% --->"),col="green")}
+            }
 
         #Lower end of CDF confidence interval for control mean
-            c=LPM.VaR((confidence.interval+(1-confidence.interval)/2),1,control,extend=extend)
-            d=LPM.VaR(.5,1,control,extend=extend)
+            c=LPM.VaR(CI,1,control,extend = "yes")
+            d=mean(control)
             if(plot==TRUE){
-        abline(v=min(c,d),
-              col="blue",lwd=4, lty=3)
-            text(min(c,d),
-              pos=2,0.75,"mu-",col="blue")}
+            if(tails=="Both"|tails=="Left"){
+              abline(v=min(c,d),col="blue",lwd=4,lty=3)
+              text(min(c,d),pos=4,0.75,"mu-",col="blue")
+              text(min(c,d),pos=2,0.75,paste0( "<--- ",(1-CI)*100,"%"),col='blue')}
+            }
 
   #Effect Size Lower Bound
-        Lower.Bound.Effect=min(mean(treatment)-max(a,b),0)
+        if(tails=="Both"){
+          Lower.Bound.Effect=min(mean(treatment)-max(a,b),0) }
+        if(tails=="Left"){
+          Lower.Bound.Effect=min(mean(treatment)-max(c,d),0) }
+        if(tails=="Right"){
+          Lower.Bound.Effect=min(mean(treatment)-max(a,b),0) }
 
 
   #Effect Size Upper Bound
-        Upper.Bound.Effect=max(mean(treatment)-min(c,d),0)
+        if(tails=="Both"){
+          Upper.Bound.Effect=max(mean(treatment)-min(c,d),0) }
+        if(tails=="Left"){
+          Upper.Bound.Effect=max(mean(treatment)-min(c,d),0) }
+        if(tails=="Right"){
+          Upper.Bound.Effect=max(mean(treatment)-min(a,b),0) }
 
   #Certainty Statistic and Effect Size Given Confidence Interval
         return(list("Control Mean" = mean(control),"Treatment Mean" = mean(treatment),"Grand Mean" = mean.of.means,"Control CDF" =LPM_ratio.1,"Treatment CDF" = LPM_ratio.2, "Certainty" = NNS.ANOVA.rho,"Lower Bound Effect"=Lower.Bound.Effect,"Upper Bound Effect"=Upper.Bound.Effect))
