@@ -4,7 +4,7 @@
 #'
 #' @param x Text A two column dataset should be used.  Concatenate text from original sources to comply with format.  Also note the possiblity of factors in \code{"DV"}, so \code{"as.numeric(as.character(...))"} is used to avoid issues.
 #' @param oos Out-of-sample text dataset to be classified.
-#' @param names Column names for \code{"IV"}.  Defaults to FALSE.
+#' @param names Column names for \code{"IV"} and \code{"oos"}.  Defaults to FALSE.
 #' @return Returns the text as independent variables \code{"IV"} and the classification as the dependent variable \code{"DV"}.  Out-of-sample independent variables are returned with \code{"OOS"}.
 #' @keywords document term matrix
 #' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
@@ -19,12 +19,12 @@
 #' NNS.term.matrix(x)
 #'
 #'
-#' ## NYT Example
+#' ### NYT Example
 #' \dontrun{
 #' require(RTextTools)
 #' data(NYTimes)
 #'
-#' ## Concatenate Columns 3 and 4 containing text, with column 5 as DV
+#' ### Concatenate Columns 3 and 4 containing text, with column 5 as DV
 #' NYT=data.frame(cbind(paste(NYTimes[,3],NYTimes[,4],sep = " "),
 #'                      as.numeric(as.character(NYTimes[,5]))))
 #' NNS.term.matrix(NYT)}
@@ -34,6 +34,7 @@
 NNS.term.matrix <- function(x, oos=NULL,names=FALSE){
 
   p=length(oos)
+
   x=t(t(x))
   n=nrow(x)
 
@@ -47,7 +48,7 @@ NNS.term.matrix <- function(x, oos=NULL,names=FALSE){
   }
 
   #Use all lowercase to simplify instances
-  x[,1]=tolower(mgsub(c(",",";",":","'s"),x[,1]))
+  x[,1]=tolower(mgsub(c(",",";",":","'s"," . "),x[,1]))
 
   unique.vocab=unique(unlist(strsplit(as.character(x[,1]), " ", fixed = TRUE)))
 
@@ -60,39 +61,41 @@ NNS.term.matrix <- function(x, oos=NULL,names=FALSE){
                    "before","behind","below","beneath","beside","besides","between", "beyond","regarding",
                    "round", "since", "through", "throughout", "till", "down", "except","from", "addition",
                    "back","front","place","regard","inside","together","toward","under","underneath","until",
-                   "nearby","next","off","account","onto", "top","opposite","out","unto","up","within",
-                   "without")
+                   "nearby","next","off","account","onto", "top","opposite","out","unto","up","within","without","what")
+
+
 
   #Remove prepositions
-  z=length(which(unique.vocab%in%c(prepositions)))
-  if(z>0){unique.vocab=unique.vocab[-which(unique.vocab%in%c(prepositions))]}else{
+  preps=unique.vocab%in%c(prepositions)
+  z=sum(preps)
+
+
+  if(z>0){unique.vocab=unique.vocab[!preps]
+  }else{
     unique.vocab=unique.vocab
   }
 
   if(!is.null(oos)){
-    zz=length(which(oos%in%c(prepositions)))
-    if(zz>0){oos=oos[-which(oos%in%c(prepositions))]}else{
+    oos.preps=oos%in%c(prepositions)
+    zz=sum(oos.preps)
+    if(zz>0){oos=oos[!oos.preps]}else{
       oos=oos
     }}
 
-
-
-  NNS.TM=data.frame()
-  OOS.TM=data.frame()
-
-  for(vocab in unique.vocab){
-    for(i in 1:n){
-      NNS.TM[i,which(unique.vocab==vocab)]=sum(unlist(strsplit(as.character(x[i,1]), " ", fixed = TRUE))==vocab)
-    }
-    for(i in 1:p){
-      OOS.TM[i,which(unique.vocab==vocab)]=sum(unlist(strsplit(as.character(oos[i]), " ", fixed = TRUE))==vocab)
-    }
-  }
+  NNS.TM=(t(sapply(1:length(x[,1]),function(i) str_count(x[i,1],unique.vocab))))
 
   if(names==TRUE){
-  colnames(NNS.TM)=c(unique.vocab)}
+  colnames(NNS.TM)=c(unique.vocab)
+  }
 
+  if(!is.null(oos)){
+  OOS.TM=(t(sapply(1:length(oos),function(i) str_count(oos[i],unique.vocab))))
+  if(names==TRUE){
+    colnames(OOS.TM)=c(unique.vocab)
+  }
   return(list("IV"=NNS.TM,"DV"=as.numeric(as.character(x[,2])),"OOS"=OOS.TM))
-
+  }else{
+    return(list("IV"=NNS.TM,"DV"=as.numeric(as.character(x[,2]))))
+    }
 
 }
